@@ -89,22 +89,22 @@ readPath <- function (path, flipY, crop, forceStack, verbosity, labelFormat, sin
         addAttributes <- function (im)
         {
             attribs <- attributes(im)
+            jsonPath <- file.path(outputDir, paste(as.character(im),"json",sep="."))
+            
+            if (is.null(attribs$.bidsJson) && file.exists(jsonPath))
+                attribs$.bidsJson <- paste(readLines(jsonPath, encoding="UTF-8"), collapse="\n")
+            
             if (!is.null(attribs$.bidsJson))
             {
                 attribs <- c(attribs, fromBidsJson(attribs$.bidsJson, rename=convertAttributes))
                 attribs$.bidsJson <- NULL
-            }
-            else
-            {
-                jsonPath <- file.path(outputDir, paste(as.character(im),"json",sep="."))
-                if (file.exists(jsonPath))
-                    attribs <- c(attribs, fromBidsJson(jsonPath, rename=convertAttributes))
+                attributes(im) <- attribs
             }
             
-            attributes(im) <- attribs
             return (im)
         }
-        results <- lapply(results, addAttributes)
+        if (requireNamespace("jsonlite", quietly=TRUE))
+            results <- lapply(results, addAttributes)
     }
     
     return (results)
@@ -187,7 +187,10 @@ readPath <- function (path, flipY, crop, forceStack, verbosity, labelFormat, sin
 #' @return \code{readDicom} and \code{convertDicom} return a list of
 #'   \code{niftiImage} objects if \code{output} is \code{NULL}; otherwise
 #'   (invisibly) a vector of paths to NIfTI-1 files created in the target
-#'   directory. The \code{scanDicom} function returns a data frame containing
+#'   directory. Returned images typically have attributes containing additional
+#'   metadata extracted from the DICOM headers, either in a JSON string or (if
+#'   the \code{jsonlite} package is available), in individually parsed
+#'   elements. The \code{scanDicom} function returns a data frame containing
 #'   information about each DICOM series found. \code{sortDicom} is mostly
 #'   called for its side-effect, but also (invisibly) returns a list detailing
 #'   source and target paths.
